==> react-lds-8.7.0.tgz: package/es/components/Popover/Popover.js <==
import "core-js/modules/es7.symbol.async-iterator";
import "core-js/modules/es6.symbol";
import "core-js/modules/es6.object.assign";
import "core-js/modules/es6.object.set-prototype-of";
import "core-js/modules/web.dom.iterable";
import "core-js/modules/es6.array.iterator";
import "core-js/modules/es6.object.to-string";
import "core-js/modules/es6.object.keys";
import "core-js/modules/es7.array.includes";
import "core-js/modules/es6.string.includes";

function _typeof(obj) { if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } return _assertThisInitialized(self); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import React, { Component } from 'react';
import PropTypes from 'prop-types';
import cx from 'classnames';
import omit from 'lodash-es/omit';
import { THEMES, getThemeClass } from '../../utils';
import { IconButton } from '../Button'; // https://github.com/oliviertassinari/babel-plugin-transform-react-remove-prop-types#is-it-safe

var propTypes = {
  /**
   * Open popover
   */
  open: PropTypes.bool,

  /**
   * Show close button
   */
  closeable: PropTypes.bool,

  /**
   * onClose handler
   */
  onClose: PropTypes.func.isRequired,

  /**
   * Popover header content
   */
  header: PropTypes.node,

  /**
   * Popover body content
   */
  body: PropTypes.node,

  /**
   * Popover footer content
   */
  footer: PropTypes.node,

  /**
   * Additional css classes
   */
  className: PropTypes.string,

  /**
   * Optional panel layout
   */
  panels: PropTypes.bool,

  /**
   * Optional position of nubbin. Positions: left, left-top, left-bottom,
   * top-left, top-right, right-top, right-bottom, bottom-left, bottom-right
   */
  nubbin: PropTypes.oneOf(['left', 'left-top', 'left-top-corner', 'left-bottom', 'left-bottom-corner', 'top-left', 'top-left-corner', 'top-right', 'top-right-corner', 'right-top', 'right-top-corner', 'right-bottom', 'right-bottom-corner', 'bottom-left', 'bottom-left-corner', 'bottom-right', 'bottom-right-corner']),

  /**
   * Optional custom Header theme. Themes: warning, error, success, info
   */
  customHeaderTheme: PropTypes.oneOf(THEMES),

  /**
   * themes: alt-inverse, default, error, info, inverse, offline, shade, success, warning
   */
  theme: PropTypes.oneOf(THEMES)
};

var Popover =
/*#__PURE__*/
function (_Component) {
  _inherits(Popover, _Component);

  _createClass(Popover, null, [{
    key: "shouldInvertIcon",
    value: function shouldInvertIcon(themeStr) {
      if (typeof themeStr === 'string') {
        return themeStr.includes('error') || themeStr.includes('success') || themeStr.includes('info') || themeStr.includes('offline');
      }

      return false;
    }
  }]);

  function Popover(props, _ref) {
    var cssPrefix = _ref.cssPrefix;

    _classCallCheck(this, Popover);

    return _possibleConstructorReturn(this, _getPrototypeOf(Popover).call(this, props, {
      cssPrefix: cssPrefix
    }));
  }

  _createClass(Popover, [{
    key: "renderHeader",
    value: function renderHeader() {
      var _this$props = this.props,
          header = _this$props.header,
          panels = _this$props.panels,
          customHeaderTheme = _this$props.customHeaderTheme;
      var headerClasses = ['slds-popover__header', getThemeClass(customHeaderTheme)];
      var headerContent;
      var borderRadius;

      if (panels && !customHeaderTheme) {
        headerContent = React.createElement("h2", {
          className: "slds-text-heading_small slds-p-around_xxx-small"
        }, header);
        borderRadius = {
          borderTopLeftRadius: 'calc(0.25rem - 1px)',
          borderTopRightRadius: 'calc(0.25rem - 1px)'
        };
      } else {
        headerContent = header;
      }

      return React.createElement("header", {
        className: cx(headerClasses),
        style: borderRadius
      }, headerContent);
    }
  }, {
    key: "renderBody",
    value: function renderBody() {
      var body = this.props.body;
      return React.createElement("div", {
        className: "slds-popover__body"
      }, body);
    }
  }, {
    key: "renderFooter",
    value: function renderFooter() {
      var footer = this.props.footer;
      return React.createElement("footer", {
        className: "slds-popover__footer"
      }, React.createElement("p", null, footer));
    }
  }, {
    key: "renderCloseButton",
    value: function renderCloseButton() {
      var _this$props2 = this.props,
          onClose = _this$props2.onClose,
          customHeaderTheme = _this$props2.customHeaderTheme,
          theme = _this$props2.theme;
      var invertIcon = Popover.shouldInvertIcon(customHeaderTheme || theme);
      var closeButtonClasses = ['slds-float_right', 'slds-popover__close'];
      return React.createElement(IconButton, {
        flavor: invertIcon ? 'inverse' : null,
        className: cx(closeButtonClasses),
        onClick: onClose,
        size: "small",
        sprite: "utility",
        icon: "close"
      });
    }
  }, {
    key: "render",
    value: function render() {
      var _this$props3 = this.props,
          className = _this$props3.className,
          closeable = _this$props3.closeable,
          open = _this$props3.open,
          customHeaderTheme = _this$props3.customHeaderTheme,
          nubbin = _this$props3.nubbin,
          panels = _this$props3.panels,
          header = _this$props3.header,
          body = _this$props3.body,
          footer = _this$props3.footer,
          theme = _this$props3.theme;
      var rest = omit(this.props, Object.keys(propTypes));
      var sldsClasses = ['slds-popover', _defineProperty({}, "slds-nubbin_".concat(nubbin), !!nubbin), {
        'slds-popover_panel': panels && !customHeaderTheme
      }, {
        'slds-hide': !open
      }, getThemeClass(theme), className];
      return React.createElement("section", _extends({}, rest, {
        className: cx(sldsClasses),
        role: "dialog"
      }), closeable ? this.renderCloseButton() : null, header ? this.renderHeader() : null, body ? this.renderBody() : null, footer ? this.renderFooter() : null);
    }
  }]);

  return Popover;
}(Component);

_defineProperty(Popover, "defaultProps", {
  body: null,
  header: null,
  footer: null,
  className: null,
  customHeaderTheme: null,
  open: false,
  closeable: true,
  panels: false,
  nubbin: 'bottom-left',
  theme: null
});

Popover.propTypes = process.env.NODE_ENV !== "production" ? propTypes : {};
export default Popover;

==> react-lds-9.1.0.tgz: package/es/components/Popover/Popover.js <==
import "core-js/modules/es.symbol";
import "core-js/modules/es.symbol.description";
import "core-js/modules/es.symbol.iterator";
import "core-js/modules/es.array.includes";
import "core-js/modules/es.array.iterator";
import "core-js/modules/es.object.assign";
import "core-js/modules/es.object.get-prototype-of";
import "core-js/modules/es.object.keys";
import "core-js/modules/es.object.set-prototype-of";
import "core-js/modules/es.object.to-string";
import "core-js/modules/es.string.includes";
import "core-js/modules/es.string.iterator";
import "core-js/modules/web.dom-collections.iterator";

function _typeof(obj) { if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } return _assertThisInitialized(self); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import React, { Component } from 'react';
import PropTypes from 'prop-types';
import cx from 'classnames';
import omit from 'lodash-es/omit';
import { THEMES, getThemeClass } from '../../utils';
import { IconButton } from '../Button'; // https://github.com/oliviertassinari/babel-plugin-transform-react-remove-prop-types#is-it-safe

var propTypes = {
  /**
   * Open popover
   */
  open: PropTypes.bool,

  /**
   * Show close button
   */
  closeable: PropTypes.bool,

  /**
   * onClose handler
   */
  onClose: PropTypes.func.isRequired,

  /**
   * Popover header content
   */
  header: PropTypes.node,

  /**
   * Popover body content
   */
  body: PropTypes.node,

  /**
   * Popover footer content
   */
  footer: PropTypes.node,

  /**
   * Additional css classes
   */
  className: PropTypes.string,

  /**
   * Optional panel layout
   */
  panels: PropTypes.bool,

  /**
   * Optional position of nubbin. Positions: left, left-top, left-bottom,
   * top-left, top-right, right-top, right-bottom, bottom-left, bottom-right
   */
  nubbin: PropTypes.oneOf(['left', 'left-top', 'left-top-corner', 'left-bottom', 'left-bottom-corner', 'top-left', 'top-left-corner', 'top-right', 'top-right-corner', 'right-top', 'right-top-corner', 'right-bottom', 'right-bottom-corner', 'bottom-left', 'bottom-left-corner', 'bottom-right', 'bottom-right-corner']),

  /**
   * Optional custom Header theme. Themes: warning, error, success, info
   */
  customHeaderTheme: PropTypes.oneOf(THEMES),

  /**
   * themes: alt-inverse, default, error, info, inverse, offline, shade, success, warning
   */
  theme: PropTypes.oneOf(THEMES)
};

var Popover =
/*#__PURE__*/
function (_Component) {
  _inherits(Popover, _Component);

  _createClass(Popover, null, [{
    key: "shouldInvertIcon",
    value: function shouldInvertIcon(themeStr) {
      if (typeof themeStr === 'string') {
        return themeStr.includes('error') || themeStr.includes('success') || themeStr.includes('info') || themeStr.includes('offline');
      }

      return false;
    }
  }]);

  function Popover(props, _ref) {
    var cssPrefix = _ref.cssPrefix;

    _classCallCheck(this, Popover);

    return _possibleConstructorReturn(this, _getPrototypeOf(Popover).call(this, props, {
      cssPrefix: cssPrefix
    }));
  }

  _createClass(Popover, [{
    key: "renderHeader",
    value: function renderHeader() {
      var _this$props = this.props,
          header = _this$props.header,
          panels = _this$props.panels,
          customHeaderTheme = _this$props.customHeaderTheme;
      var headerClasses = ['slds-popover__header', getThemeClass(customHeaderTheme)];
      var headerContent;
      var borderRadius;

      if (panels && !customHeaderTheme) {
        headerContent = React.createElement("h2", {
          className: "slds-text-heading_small slds-p-around_xxx-small"
        }, header);
        borderRadius = {
          borderTopLeftRadius: 'calc(0.25rem - 1px)',
          borderTopRightRadius: 'calc(0.25rem - 1px)'
        };
      } else {
        headerContent = header;
      }

      return React.createElement("header", {
        className: cx(headerClasses),
        style: borderRadius
      }, headerContent);
    }
  }, {
    key: "renderBody",
    value: function renderBody() {
      var body = this.props.body;
      return React.createElement("div", {
        className: "slds-popover__body"
      }, body);
    }
  }, {
    key: "renderFooter",
    value: function renderFooter() {
      var footer = this.props.footer;
      return React.createElement("footer", {
        className: "slds-popover__footer"
      }, React.createElement("p", null, footer));
    }
  }, {
    key: "renderCloseButton",
    value: function renderCloseButton() {
      var _this$props2 = this.props,
          onClose = _this$props2.onClose,
          customHeaderTheme = _this$props2.customHeaderTheme,
          theme = _this$props2.theme;
      var invertIcon = Popover.shouldInvertIcon(customHeaderTheme || theme);
      var closeButtonClasses = ['slds-float_right', 'slds-popover__close'];
      return React.createElement(IconButton, {
        flavor: invertIcon ? 'inverse' : null,
        className: cx(closeButtonClasses),
        onClick: onClose,
        size: "small",
        sprite: "utility",
        icon: "close"
      });
    }
  }, {
    key: "render",
    value: function render() {
      var _this$props3 = this.props,
          className = _this$props3.className,
          closeable = _this$props3.closeable,
          open = _this$props3.open,
          customHeaderTheme = _this$props3.customHeaderTheme,
          nubbin = _this$props3.nubbin,
          panels = _this$props3.panels,
          header = _this$props3.header,
          body = _this$props3.body,
          footer = _this$props3.footer,
          theme = _this$props3.theme;
      var rest = omit(this.props, Object.keys(propTypes));
      var sldsClasses = ['slds-popover', _defineProperty({}, "slds-nubbin_".concat(nubbin), !!nubbin), {
        'slds-popover_panel': panels && !customHeaderTheme
      }, {
        'slds-hide': !open
      }, getThemeClass(theme), className];
      return React.createElement("section", _extends({}, rest, {
        className: cx(sldsClasses),
        role: "dialog"
      }), closeable ? this.renderCloseButton() : null, header ? this.renderHeader() : null, body ? this.renderBody() : null, footer ? this.renderFooter() : null);
    }
  }]);

  return Popover;
}(Component);

_defineProperty(Popover, "defaultProps", {
  body: null,
  header: null,
  footer: null,
  className: null,
  customHeaderTheme: null,
  open: false,
  closeable: true,
  panels: false,
  nubbin: 'bottom-left',
  theme: null
});

Popover.propTypes = process.env.NODE_ENV !== "production" ? propTypes : {};
export default Popover;
